@@ -16,6 +16,8 @@ from .voter import Voter
 from .feed import Feed
 from .trained_model import TrainedModel
 from .feed_result import FeedResult
+from .evaluated_model import EvaluatedModel
+from .evaluated_feed import EvaluatedFeed
 
 # Expose all model classes
 __all__ = [
@@ -32,7 +34,9 @@ __all__ = [
     'TrainedModel',
     'FeedResult',
     'Symbol',
-    'Tick'
+    'Tick',
+    'EvaluatedModel',
+    'EvaluatedFeed'
 ]
 
 
