@@ -417,21 +417,58 @@ class Tick(Base):
         session.commit()
 
 
-class EvaluatedTarget(Base):
-    __tablename__ = "EvaluatedTarget"
+class EvaluatedModel(Base):
+    __tablename__ = "EvaluatedModel"
     __table_args__ = (
-        UniqueConstraint('chain', 'model', name='uq_evaluated'),
-        Index("et_chain_model_index", "chain", "model"),
+        UniqueConstraint('chain', 'model', 'voting_round', name='uq_evaluated_model'),
+        Index("et_chain_model_voting_round_index", "chain", "model", "voting_round"),
+    )
+    # Change `id` to an auto-incrementing integer primary key
+    id = Column(Integer, primary_key=True, autoincrement=True, nullable=False)
+    chain = Column(String(15), nullable=False)
+    model = Column(String(50), nullable=False)
+    feed = Column(String(25), nullable=False)
+    voting_round = Column(Integer, nullable=False)
+    prediction = Column(Float, nullable=True)  # Correction Factor. Typically, the last observed Moving Average.
+    target = Column(Float, nullable=True)
+    diff = Column(Float, nullable=True)
+    diff_clean = Column(Float, nullable=True)
+    diff_ema = Column(Float, nullable=True)
+    original_error = Column(Float, nullable=True)
+    revision_confidence = Column(Float, nullable=True)
+    revision_confidence_ema = Column(Float, nullable=True)
+    revised_prediction = Column(Float, nullable=True)
+    revised_error = Column(Float, nullable=True)
+    rmse = Column(Float, nullable=True)
+    r2 = Column(Float, nullable=True)
+    score = Column(Float, nullable=True)
+    stability_factor = Column(Float, nullable=True)
+    revised_error_confidence = Column(Float, nullable=True)
+    evaluation_count = Column(Integer, nullable=False, autoincrement=True)
+    status = Column(Integer, nullable=True)
+    # Timestamp with default UTC now
+    timestamp = Column(DateTime, default=datetime.utcnow, nullable=False)
+
+    def __repr__(self):
+        return str(self.to_dict())
+
+    def to_dict(self):
+        return {c.key: getattr(self, c.key) for c in inspect(self).mapper.column_attrs}
+
+
+class EvaluatedFeed(Base):
+    __tablename__ = "EvaluatedFeed"
+    __table_args__ = (
+        UniqueConstraint('chain', 'feed', name='uq_evaluated_feed'),
+        Index("et_chain_feed_index", "chain", "feed"),
     )
     # Change `id` to an auto-incrementing integer primary key
     id = Column(Integer, primary_key=True, autoincrement=True, nullable=False)
     chain = Column(String(15), nullable=True)
-    model = Column(String(50), nullable=False)
-    target = Column(String(50), nullable=True)
     feed = Column(String(25), nullable=True)
     correction_factor = Column(Float, nullable=True)  # Correction Factor. Typically, the last observed Moving Average.
-    correction_r2_score = Column(Float, nullable=True)
-    correction_rmse_score = Column(Float, nullable=True)
+    r2_score = Column(Float, nullable=True)
+    rmse_score = Column(Float, nullable=True)
     evaluation_voting_round = Column(Integer, nullable=True)
     status = Column(Integer, nullable=True)
     # Timestamp with default UTC now
@@ -441,4 +478,5 @@ class EvaluatedTarget(Base):
         return str(self.to_dict())
 
     def to_dict(self):
-        return {c.key: getattr(self, c.key) for c in inspect(self).mapper.column_attrs}
\ No newline at end of file
+        return {c.key: getattr(self, c.key) for c in inspect(self).mapper.column_attrs}
+
