@@ -14,8 +14,10 @@ class Tick(Base):
     chain = Column(String(15), nullable=False)
     voting_round = Column(Integer, nullable=False)
     symbol = Column(String(30), nullable=False)
+    idx = Column(Integer, nullable=False)
     position = Column(Integer, nullable=False)
     label = Column(String(20), nullable=False)
+    feature = Column(String(50), nullable=False)
     value = Column(Float, nullable=False)
     timestamp = Column(String(50), nullable=False)
 
